@@ -1904,7 +1904,7 @@ int get_geometry(char *geometry, size_t size, int verbose, int ctl1, int ctl2)
         h,
         x,
         y;
-    char local_temp[20];
+    char local_temp[BUFSIZ];
 
     /* get height, width - CSI 8 ; height ; width t */
     csi_print1(ctl1);
@@ -2011,7 +2011,7 @@ void usage(int status)
         printf("  %-35s %s\n", "--help, -h", "print this help and exit");
         printf("  %-35s %s\n", "--version", "print the version number and exit");
         printf("\n");
-        printf("Report bugs to <jess@thrysoee.dk>\n");
+        printf("See xtermcontrol(1) manpage for more information.\n");
     }
 
     do_exit(status);
